import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { Dropdown, DropdownContext } from "../../dropdown";
import { bool, element, string } from "prop-types";
import { createIconForControl } from "../../icons";
import { isNil } from "lodash";
import { throwWhenUnsupportedPropIsProvided } from "../../shared";
import { useContext } from "react";
const UNSUPPORTED_PROPS = ["content", "flag", "image", "label"];
const propTypes = {
  /**
   * The item text.
   */
  text: string,

  /**
   * The item value.
   */
  value: string,

  /**
   * An item can navigate to a page.
   */
  href: string,

  /**
   * A description to display with less emphasize.
   */
  description: string,

  /**
   * An item can display an icon before his text.
   */
  icon: element,

  /**
   * A disabled item cannot be selected.
   */
  disabled: bool
};
const defaultProps = {
  disabled: false
};
export function DropdownMenuItem(props) {
  const {
    text,
    icon,
    description
  } = props,
        rest = _objectWithoutProperties(props, ["text", "icon", "description"]);

  const context = useContext(DropdownContext);
  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, "@orbit-ui/react-components/dropdown-menu/item");

  const renderText = () => {
    if (!isNil(text)) {
      return /*#__PURE__*/React.createElement("span", {
        className: "text"
      }, text);
    }
  };

  const renderDescription = () => {
    if (!isNil(description)) {
      return /*#__PURE__*/React.createElement("span", {
        className: "description"
      }, description);
    }
  };

  const renderContent = () => {
    let left;

    if (!isNil(icon)) {
      left = createIconForControl(icon, context.size);
    }

    return /*#__PURE__*/React.createElement(React.Fragment, null, !isNil(left) && left, renderText(), renderDescription());
  };

  return /*#__PURE__*/React.createElement(Dropdown.Item, rest, renderContent());
}
DropdownMenuItem.displayName = "DropdownMenuItem";
DropdownMenuItem.propTypes = propTypes;
DropdownMenuItem.defaultProps = defaultProps;