import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import { INPUT_UNSUPPORTED_PROPS, Input } from "../../input";
import { bool, element, func, number, object, oneOf, oneOfType } from "prop-types";
import { forwardRef } from "react";
import { isNil } from "lodash";
import { throwWhenUnsupportedPropIsProvided } from "../../shared"; // Sizes constants are duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise it will not render properly in the docs.

const SIZES = ["small", "medium", "large"];
const DEFAULT_SIZE = "medium";
const COMPONENT_NAME = "@orbit-ui/react-components/number-input";
const UNSUPPORTED_PROPS = [...INPUT_UNSUPPORTED_PROPS, "button", "iconsPosition", "type"]; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged.

const INPUT_PROP_TYPES = {
  /**
   * Whether or not the input should autofocus on render.
   */
  autofocus: bool,

  /**
   * Delay before trying to autofocus.
   */
  autofocusDelay: number,

  /**
   * A React component displayed before or after the prompt based on "iconPosition".
   */
  icon: element,

  /**
   * An input can vary in sizes.
   */
  size: oneOf(SIZES),

  /**
   * @ignore
   */
  forwardedRef: oneOfType([object, func])
}; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged.

const INPUT_DEFAULT_PROPS = {
  autofocus: false,
  size: DEFAULT_SIZE
};

const propTypes = _objectSpread({
  /**
   * The value of the input.
   */
  value: number,

  /**
   * The default value of the input.
   */
  defaultValue: number,

  /**
   * The minimum value of the input.
   */
  min: number,

  /**
   * The maximum value of the input.
   */
  max: number,

  /**
   * The increment step of the input value.
   */
  step: number
}, INPUT_PROP_TYPES);

const defaultProps = _objectSpread({}, INPUT_DEFAULT_PROPS);

export function PureNumberInput(props) {
  const {
    icon,
    loading,
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["icon", "loading", "forwardedRef"]);

  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, COMPONENT_NAME);
  return /*#__PURE__*/React.createElement(Input, Object.assign({
    type: "number",
    icon: icon,
    iconPosition: !isNil(icon) || !isNil(loading) ? "left" : undefined,
    loading: loading,
    ref: forwardedRef,
    __componentName: COMPONENT_NAME
  }, rest));
}
PureNumberInput.displayName = "PureNumberInput";
PureNumberInput.propTypes = propTypes;
PureNumberInput.defaultProps = defaultProps;
export const NumberInput = forwardRef((props, ref) => /*#__PURE__*/React.createElement(PureNumberInput, Object.assign({}, props, {
  forwardedRef: ref
})));